/*****************************************************************************
 * Copyright (C) 2024
 *
 * Michiel Broek <mbroek at mbse dot eu>
 *
 * This file is part of mbsePi-apps
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * BrewCloud is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ThermFerm; see the file COPYING.  If not, write to the Free
 * Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *****************************************************************************/


function createDelElements() {
 $('#eventWindow').jqxWindow({
  theme: theme,
  position: { x: 490, y: 210 },
  width: 300,
  height: 175,
  resizable: false,
  isModal: true,
  modalOpacity: 0.4,
  okButton: $('#delOk'),
  cancelButton: $('#delCancel'),
  initContent: function() {
   $('#delOk').jqxButton({ template: 'danger', width: '65px', theme: theme });
   $('#delCancel').jqxButton({ template: 'success', width: '65px', theme: theme });
   $('#delCancel').focus();
  }
 });
 $('#eventWindow').jqxWindow('hide');
}


$(document).ready(function() {
 var dataRecord = {},
 source = {
  datatype: 'json',
  cache: false,
  datafields: [
   { name: 'uuid', type: 'string' },
   { name: 'type', type: 'string' },
   { name: 'address', type: 'string' },
   { name: 'subdevice', type: 'int' },
   { name: 'inuse', type: 'int' },
   { name: 'description', type: 'string' },
   { name: 'direction', type: 'string' },
   { name: 'value', type: 'int' },
   { name: 'timestamp', type: 'int' }
  ],
  id: 'uuid',
  url: 'getdevices.php'
 },
 dataAdapter = new $.jqx.dataAdapter(source),
 editrow = -1;

 // initialize the input fields.
 $('#dev_uuid').jqxInput({ theme: theme, width: 640, height: 23 });
 $('#dev_description').jqxInput({ theme: theme, width: 640, height: 23 });
 $('#dev_type').jqxDropDownList({
  theme: theme,
  source: DeviceTypeAdapter,
  valueMember: 'mno',
  displayMember: 'en',
  width: 180,
  height: 23,
  autoDropDownHeight: true
 });
 $('#dev_direction').jqxDropDownList({
  theme: theme,
  source: DeviceDirectionAdapter,
  valueMember: 'mno',
  displayMember: 'en',
  width: 180,
  height: 23,
  autoDropDownHeight: true
 });


 // initialize jqxGrid
 $('#jqxgrid').jqxGrid({
  width: 1280,
  height: 630,
  source: dataAdapter,
  theme: theme,
  showstatusbar: true,
  renderstatusbar: function(statusbar) {
   var rowCount = $("#jqxgrid").jqxGrid('getrows').length;
   statusbar.append('<div style="float: left; margin: 8px; color: orange !important;">Total items: ' + rowCount + '</div>');
   var container, addButton, impButton;
   container = $('<div style="overflow: hidden; position: relative; margin: 5px;"></div>');
   addButton = $('<div style="float: right; margin-right: 15px;"><img style="position: relative; margin-top: 2px;" ' +
     'src="images/add.png"/><span style="margin-left: 4px; position: relative; top: -4px;">Nieuw</span></div>');
   container.append(addButton);
   statusbar.append(container);
   addButton.jqxButton({ theme: theme, width: 90, height: 17 });
   // add new row.
   addButton.click(function(event) {
    editrow = -1;
    $('#popupWindow').jqxWindow({ position: { x: 110, y: 30 } });

    dataRecord.uuid = '';
    $('#popupWindow').jqxWindow('open');
   });
  },
  columns: [
   { text: 'Address', datafield: 'address', width: 200 },
   { text: 'Subdevice', datafield: 'subdevice', width: 100 },
   { text: 'Direction', datafield: 'direction', width: 120 },
   { text: 'Value', datafield: 'value', width: 80 },
   { text: 'Description', datafield: 'description' },
   { text: 'Last change', datafield: 'timestamp', width: 200,
     cellsrenderer: function(index, datafield, value, defaultvalue, column, rowdata) {
      var tzoffset = (new Date()).getTimezoneOffset() * 60000; //offset in milliseconds
      var date = new Date((value * 1000) - tzoffset).toISOString().slice(0, 19).replace("T", " ");;
      return '<span style="margin: 3px; margin-top: 6px; float: left;">' +  date + '</span>';
    }
   },
   { text: '', datafield: 'Edit', width: 100, align: 'center', columntype: 'button', cellsrenderer: function() {
    return 'Edit';
    }, buttonclick: function(row) {
     // open the popup window when the user clicks a button.
     editrow = row;
     $('#popupWindow').jqxWindow({ position: { x: 110, y: 15 } });
     dataRecord = $('#jqxgrid').jqxGrid('getrowdata', editrow);
     $('#dev_uuid').val(dataRecord.uuid);
     $('#dev_description').val(dataRecord.description);
     // dev_type
     // dev_direction
     // dev_value
     // dev_offset
     // dev_address
     // dev_subdevice
     // dev_present
     // dev_gpiopin
     // dev_inuse
     // dev_timestamp
     // dev_comment

     // show the popup window.
     $('#popupWindow').jqxWindow('open');
    }
   }
  ],
 });

 // initialize the popup window and buttons.
 $('#popupWindow').jqxWindow({
  width: 1050,
  height: 625,
  resizable: false,
  theme: theme,
  isModal: true,
  autoOpen: false,
  cancelButton: $('#Cancel'),
  modalOpacity: 0.40
 });
 $('#popupWindow').on('open', function() {
  $('#dev_description').jqxInput('selectAll');
 });
 $('#Delete').jqxButton({ template: 'danger', width: '90px', theme: theme });

 websocket.onmessage = function(evt) {
  var msg = evt.data;
  var obj = JSON.parse(msg);

  if (obj.ping) {
   websocket.send('{"pong":' + obj.ping + '}');
  }

  if (obj.type == 'device') {
   // Use the message to trigger update.
   $('#jqxgrid').jqxGrid('updatebounddata');
  }
 }
});
